### Name: go.renorm
### Title: Descent by renormalisation in space of measures under linear
###   constraints.
### Aliases: go.renorm.default go.renorm.medea medea
### Keywords: optimize design

### ** Examples

# Optimal design of observation points x_i in linear model
# y(x_i)=\sum_i f(x_i)*beta
# f is a vector function (row) and beta is a column-vector of unknown coeffs.
# Example from Atkinson & Donev "Optimum Experimental Design",
# Oxford 1992 (p.119): cubic regression through the origin.
# We are looking for an optimal design having the total mass 1
# and the barycenter 0.7
#
library(medea)
info.matrix <- function(mu,space,func,...)
{ # Information matrix
        return(t(func(space)) %*% diag(mu) %*% func(space))
}

detIM.func<-function(mu,space,...)
  { # The object function: determinant of the info matrix
       return(det(info.matrix(mu,space,...))) 
  }

detIM.grad <- function(mu,space,func,...)
  { # The gradient function
    inf.mat <- info.matrix(mu,space,func,...)
    if(det(inf.mat)>1e-10)
        res <- diag(func(space) %*% solve(inf.mat) %*% t(func(space)))
    else
        res <- rep(Inf,length=length(mu)) # exclude singular matrix case
    return( res)
  }

 x<-seq(0,1,by=0.05) # State space
 f1<-function(x) {return(x)}
 f2<-function(x) {return(x^2)}
 f3<-function(x) {return(x^3)}
 f<-function(x) {return(cbind(f1(x),f2(x),f3(x)))}

 # And here we go.renorm:
 ## Not run: 
##D res<-go.renorm(mu=NA,detIM.func,detIM.grad,minim=FALSE,tol=0.01,space=x,
##D       No.steps=10,details=TRUE,visualize=TRUE,func=f,constr=bary,
##D       cval=c(1,0.7))
##D  res
##D  res<-go.renorm(res,visualize=TRUE)
##D  # ATTENTION: the next command performs a few hundred iterations
##D  # to arive to the optimal solution:
##D  # while(!res$opt) res<-go.renorm(res)
##D  summary(res)
##D  plot(res)
## End(Not run)



